import { useAjax } from '@/Hook/useAjax';
import { getProjectListApi } from '@/pages/weComTask/API/businessPlan/create';
import { Button, Card, DatePicker, Input, Space, Table } from 'antd';
import React, { useEffect, useState } from 'react';
import taskListColumns from './tableConfig';
import dayjs from 'dayjs';
import { SearchOutlined } from '@ant-design/icons';
import { api_corpUser_allOfUser, getAllBookApi, getBookPlatInfoAllApi } from '@/pages/weComTask/API/global';
import Log from './log';

/**
 * 任务列表
 * @returns 
 */
const TaskList: React.FC = () => {

    /***********************************************/
    const projectName = sessionStorage.getItem('CAMPCORP')
    const [queryForm, setQueryForm] = useState<BUSINES_SPLAN_API.GetProjectListProps>({ pageNum: 1, pageSize: 20, projectName })
    const [queryFormNew, setQueryFormNew] = useState<BUSINES_SPLAN_API.GetProjectListProps>({ pageNum: 1, pageSize: 20, projectName })
    const [bookPlatForm, setBookPlatForm] = useState<TASK_CREATE.BookPlatFormProps[]>([])
    const [bookList, setBookList] = useState<TASK_CREATE.BookListProps[]>([])
    const [logOpenData, setLogOpenData] = useState<{ visible: boolean, data: any }>({ visible: false, data: {} })
    const [corpList, setCorpList] = useState<TASK_CREATE.CorpListProps[]>([])

    const getAllBook = useAjax(() => getAllBookApi()) //书
    const getBookPlatInfoAll = useAjax(() => getBookPlatInfoAllApi()) //书城
    const getProjectList = useAjax((params) => getProjectListApi(params))
    const corpUser_allOfUser = useAjax((params) => api_corpUser_allOfUser(params))
    /***********************************************/

    /** 人的企业 */
    useEffect(() => {
        if (sessionStorage.getItem('userId')) {
            corpUser_allOfUser.run(sessionStorage.getItem('userId')).then(res => {
                if (res?.data) {
                    setCorpList(res?.data?.map((item: { t1: { corpId: any; corpName: any; }; t2: any; }) => ({
                        ...item.t1,
                        value: item.t1.corpId,
                        label: item.t1.corpName,
                        weList: item.t2
                    })))
                }
            })
        }
    }, [])

    useEffect(() => {
        const projectName = sessionStorage.getItem('CAMPCORP')
        if (projectName) {
            sessionStorage.removeItem('CAMPCORP')
        }
    }, [])

    useEffect(() => {
        getBookPlatInfoAll.run().then((res) => {
            if (res?.data) setBookPlatForm(res.data)
        })
        getAllBook.run().then(res => {
            if (res?.data) {
                setBookList(res.data)
            }
        })
    }, [])

    useEffect(() => {
        getProjectList.run(queryFormNew)
    }, [queryFormNew])

    const handleLog = (data: any) => {
        setLogOpenData({ visible: true, data })
    }

    return <Card>
        <div style={{ display: 'flex', gap: 10, marginBottom: 10 }}>
            <Space.Compact>
                <Button>任务名称</Button>
                <Input placeholder='请输入任务名称' allowClear value={queryForm?.projectName} onChange={(e) => setQueryForm({ ...queryForm, projectName: e.target.value })} />
            </Space.Compact>
            <Space.Compact>
                <Button>创建时间</Button>
                <DatePicker.RangePicker
                    placeholder={["创建时间开始", "创建时间结束"]}
                    value={queryForm?.createTimeMin ? [dayjs(queryForm?.createTimeMin), dayjs(queryForm?.createTimeMax)] : undefined}
                    onChange={(_, options) => {
                        const newQueryForm = { ...queryForm }
                        if (options?.[0]) {
                            newQueryForm.createTimeMin = options?.[0] + ' 00:00:00'
                            newQueryForm.createTimeMax = options?.[1] + ' 23:59:59'
                        } else {
                            delete newQueryForm?.createTimeMin
                            delete newQueryForm?.createTimeMax
                        }
                        setQueryForm(newQueryForm)
                    }}
                />
            </Space.Compact>
            <Button
                type='primary'
                onClick={() => {
                    setQueryFormNew({ ...queryForm, pageNum: 1 })
                }}
                icon={<SearchOutlined />}
            >搜索</Button>
        </div>
        <Table
            dataSource={getProjectList?.data?.data?.records}
            columns={taskListColumns(bookPlatForm, bookList, handleLog)}
            rowKey={'id'}
            bordered={true}
            size='small'
            scroll={{ y: 600, x: 1200 }}
            pagination={{
                current: getProjectList?.data?.data?.current,
                pageSize: getProjectList?.data?.data?.size,
                total: getProjectList?.data?.data?.total,
                showSizeChanger: true,
                onChange: (page, pageSize) => {
                    setQueryFormNew({ ...queryFormNew, pageNum: page, pageSize })
                    setQueryForm({ ...queryForm, pageNum: page, pageSize })
                }
            }}
        />

        {/* 日志 */}
        {logOpenData.visible && <Log
            {...logOpenData}
            corpList={corpList}
            bookPlatForm={bookPlatForm}
            bookList={bookList}
            onClose={() => {
                setLogOpenData({ visible: false, data: undefined })
            }}
        />}
    </Card>
};

export default TaskList;